ConstrainedHeader

Struct ConstrainedHeader 

pub struct ConstrainedHeader {
    pub connection_id: ConnectionId,
    pub seq: SequenceNumber,
    pub ack: SequenceNumber,
    pub flags: PacketFlags,
}
Constrained protocol packet header

A compact 5-byte header containing all information needed for reliable delivery.

Fields

connection_id: ConnectionId

Connection identifier (2 bytes)

seq: SequenceNumber

Sequence number for this packet (1 byte)

ack: SequenceNumber

Acknowledgment number (cumulative) (1 byte)

flags: PacketFlags

Packet flags (1 byte)

Implementations

Source

impl ConstrainedHeader

pub const fn new( connection_id: ConnectionId, seq: SequenceNumber, ack: SequenceNumber, flags: PacketFlags, ) -> Self

Create a new header with the specified fields

pub fn syn(connection_id: ConnectionId) -> Self

Create a SYN header for connection initiation

pub fn syn_ack(connection_id: ConnectionId, ack: SequenceNumber) -> Self

Create a SYN-ACK header for connection response

pub fn ack( connection_id: ConnectionId, seq: SequenceNumber, ack: SequenceNumber, ) -> Self

Create an ACK-only header

pub fn data( connection_id: ConnectionId, seq: SequenceNumber, ack: SequenceNumber, ) -> Self

Create a DATA header

pub fn fin( connection_id: ConnectionId, seq: SequenceNumber, ack: SequenceNumber, ) -> Self

Create a FIN header for connection close

pub fn reset(connection_id: ConnectionId) -> Self

Create a RST header for connection reset

pub fn ping(connection_id: ConnectionId, seq: SequenceNumber) -> Self

Create a PING header for keep-alive

pub fn pong(connection_id: ConnectionId, ack: SequenceNumber) -> Self

Create a PONG header in response to ping

pub fn to_bytes(&self) -> [u8; 5]

Serialize header to bytes

Returns a 5-byte array containing the serialized header.

pub fn from_bytes(bytes: &[u8]) -> Result<Self, ConstrainedError>

Deserialize header from bytes

Returns an error if the slice is too short.

pub const fn is_syn(&self) -> bool

Check if this is a SYN packet

pub const fn is_syn_ack(&self) -> bool

Check if this is a SYN-ACK packet

pub const fn is_ack(&self) -> bool

Check if this has the ACK flag

pub const fn is_fin(&self) -> bool

Check if this is a FIN packet

pub const fn is_rst(&self) -> bool

Check if this is a RST packet

pub const fn is_data(&self) -> bool

Check if this is a DATA packet

pub const fn is_ping(&self) -> bool

Check if this is a PING packet

pub const fn is_pong(&self) -> bool

Check if this is a PONG packet