pub enum DirectPathStatus {
Pending,
Established {
remote_addr: SocketAddr,
},
BestEffortUnavailable {
reason: DirectPathUnavailableReason,
},
Failed {
error: String,
},
}Expand description
Best-effort direct-path status for an authenticated peer.
Variants
Pending
Direct-path establishment is still in progress or may still improve later.
Established
A direct path has been established.
Fields

remote_addr: SocketAddrRemote socket address for the established direct path.
A direct path is currently unavailable, but overall connectivity can still continue.
Failed
Direct-path establishment failed in a way the caller should treat as a hard failure.