pub struct WeakPathHandle { /* private fields */ }Expand description
Weak read-only handle to a QUIC connection path.
The handle can expose retained path state after the connection/path has closed without keeping the connection alive.
Implementations
Sourceimpl WeakPathHandle
impl WeakPathHandle
Sourcepub fn upgrade(&self) -> Option<Path>
pub fn upgrade(&self) -> Option<Path>
Upgrade to a live path handle if the path’s connection is still alive.
Sourcepub fn is_alive(&self) -> bool
pub fn is_alive(&self) -> bool
Return true while the underlying path’s connection is still alive.
Sourcepub fn remote_address(&self) -> SocketAddr
pub fn remote_address(&self) -> SocketAddr
Return the retained or live peer UDP address associated with this path.
Sourcepub fn observed_external_addr(&self) -> Option<SocketAddr>
pub fn observed_external_addr(&self) -> Option<SocketAddr>
Return the retained or live external/reflexive address for this path.