pub struct BootstrapTokenStore { /* private fields */ }Expand description
A TokenStore implementation that persists tokens to the BootstrapCache.
It maintains a local synchronous cache for take operations (required by TokenStore trait)
and asynchronously updates the BootstrapCache on insert.
Implementations
Sourceimpl BootstrapTokenStore
impl BootstrapTokenStore
Sourcepub async fn new(cache: Arc<BootstrapCache>) -> Self
pub async fn new(cache: Arc<BootstrapCache>) -> Self
Create a new BootstrapTokenStore backed by the given cache.
This will initialize the local memory cache with all tokens currently in the BootstrapCache.